<?php
//
//	Module name      :	testdateutil.php
//
//	Description      :	Test file for dateutil module
//
//	Parameters       :	None
//	Notes - usage    :	None
//


//--- Include files --------------------------------------------------------------------------------



require_once("debug.php");
require_once("dateutil.php");



//--- Global constants -----------------------------------------------------------------------------



define("PAGE_TIMER_NAME", "TestPage");
define("TEST_TIMER_NAME", "TestFunc");



//--- Global variables -----------------------------------------------------------------------------



$Module_prefix = "DU";



//--- Functions code -------------------------------------------------------------------------------



function PrintFooter()
// Prints the test page footer.
{
	print "
		<!--- Start of PrintFooter ------------------------------------------------------>
		</body>
		</html>";
	$sec = DMtimerRead(PAGE_TIMER_NAME);
	print "
		<!--- End of PrintFooter -------------------------------------------------------->
		<!--- (Elapsed seconds for page construction: $sec) ------------------------->
		";
}



function PrintHeader($browser_title)
// Prints the test page header.
{
	DMtimerReset(PAGE_TIMER_NAME);
	$now = gmdate('D, d M Y H:i:s') . ' GMT';
	header('Expires: ' . $now);						// rfc2616 - Section 14.21
	header('Last-Modified: ' . $now);
	header('Cache-Control: no-store, no-cache, must-revalidate, pre-check=0, post-check=0, max-age=0'); // HTTP/1.1
	header('Pragma: no-cache'); // HTTP/1.0
	print "
		<!--- Start of PrintHeader ------------------------------------------------------>
		<html>
		<head>
			<title>$browser_title</title>
			<meta http-equiv='content-type' content='text/html; charset=iso-8859-1'>
		</head>
		<body>
		<!--- End of PrintHeader -------------------------------------------------------->
		";
}



function Test()
// Calls DPrint for each parameter passed; if ErrorMsg and Result are defined in the tested module,
// calls them and shows their values after the last parameter evaluation. Returns the value of the last
// parameter evaluation.
{
	global $Module_prefix;
	static $first_call = TRUE;

	$em_name = "${Module_prefix}ErrorMsg";
	$em = function_exists($em_name);
	$r_name = "${Module_prefix}Result";
	$r = function_exists($r_name);
	for ($i = 0; $i < func_num_args(); $i++)
		$result = DPrint(func_get_arg($i));
	if ($first_call)
	{
		$first_call = FALSE;
		$msec = 0;
	}
	else
		$msec = DMtimerRead(TEST_TIMER_NAME);
	DMTimerReset(TEST_TIMER_NAME);
	print "
		<table border=1 cellspacing=1 cellpadding=3 width=100%>
		<tr valign=top>
			<td width=1%>
				<center><font style='visibility:hidden'><b>DPrint</b></font></center>
			</td>
			<td><font size=-1>
				" . ($r ? "<b>${Module_prefix}Result:</b> '" . call_user_func($r_name) . "';" : "") . "
				" . ($em ? "<b>${Module_prefix}ErrorMsg:</b> '" . call_user_func($em_name) . "';" : "") . "
				<b>Elapsed secs from last call:</b> $msec</font>
			</td>
		</tr></table><br>
		";
	return $result;
}



//--- Main code ------------------------------------------------------------------------------------



	DSetDebugWindow(D_WIN_DEF_X, D_WIN_DEF_Y, D_WIN_DEF_WIDTH, D_WIN_DEF_HEIGHT, FALSE);
	PrintHeader("Test file for " . constant("${Module_prefix}_MODULE_NAME"));
	Test("Initial internal status");

	// Test code for dateutil.php starts here.

	Test(
			"today", DUDayNumOfYear(), DUDayNumOfYear(2005),
			"2004,2001,2000", DUDayNumOfYear(2004), DUDayNumOfYear(2001), DUDayNumOfYear(2000),
			"1996", DUDayNumOfYear(1996),
			"1970", DUDayNumOfYear(1970)
		);
	Test("-1", DUDayNumOfYear(-1));
	Test("1960", DUDayNumOfYear(1960));

	Test(
			"today", DUDayNumOfMonth(),
			"all this year", DUDayNumOfMonth(1), DUDayNumOfMonth(2), DUDayNumOfMonth(3), DUDayNumOfMonth(4),
			DUDayNumOfMonth(5), DUDayNumOfMonth(6), DUDayNumOfMonth(7), DUDayNumOfMonth(8),
			DUDayNumOfMonth(9), DUDayNumOfMonth(10), DUDayNumOfMonth(11), DUDayNumOfMonth(12),
			"today feb", DUDayNumOfMonth(2), DUDayNumOfMonth(2, 2005),
			"2004 feb", DUDayNumOfMonth(2, 2004),
			"2003 feb", DUDayNumOfMonth(2, 2003),
			"2002 feb", DUDayNumOfMonth(2, 2002),
			"2001 feb", DUDayNumOfMonth(2, 2001),
			"2000 feb", DUDayNumOfMonth(2, 2000),
			"1970 feb", DUDayNumOfMonth(2, 1970)
		);
	Test("-1 feb", DUDayNumOfMonth(2, -1));
	Test("1960 feb", DUDayNumOfMonth(2, 1960));

	Test(
			"gen..dic", DUMonthName(1), DUMonthName(2), DUMonthName(3), DUMonthName(4),
			DUMonthName(5), DUMonthName(6), DUMonthName(7), DUMonthName(8),
			DUMonthName(9), DUMonthName(10), DUMonthName(11), DUMonthName(12)
		);
	Test("0", DUMonthName(0));
	Test("13", DUMonthName(13));
	
	Test(
			"gen..dic", DUMonthShortName(1), DUMonthShortName(2), DUMonthShortName(3), DUMonthShortName(4),
			DUMonthShortName(5), DUMonthShortName(6), DUMonthShortName(7), DUMonthShortName(8),
			DUMonthShortName(9), DUMonthShortName(10), DUMonthShortName(11), DUMonthShortName(12)
		);
	Test("0", DUMonthShortName(0));
	Test("13", DUMonthShortName(13));
	
	DPrint(
			"secs", DU_MIN_SECS, DU_HOUR_SECS, DU_DAY_SECS, DU_WEEK_SECS, DU_YEAR_SECS,
			"minutes", DU_HOUR_MINS, DU_DAY_MINS, DU_WEEK_MINS, DU_YEAR_MINS,
			"hours", DU_DAY_HOURS, DU_WEEK_HOURS, DU_YEAR_HOURS,
			"days", DU_WEEK_DAYS, DU_YEAR_DAYS
		);

	Test("Test1", DUTimerReset("Test1"), DUTimerRead("Test1"));
	Test("Test2", DUTimerRead("Test2"));
	Test("Test2", DUTimerRead("Test2"));
	Test("Test3", DUTimerReset("Test3"), $t3a = DUTimerRead("Test3"), $t3b = DUTimerRead("Test3"),
			$t3a + $t3b);

	Test("01/01/2005",
			DUIso2Ts("2005"), DUIso2Ts("2005-01"), DUIso2Ts("2005-01-01"),
			DUIso2Ts("2005-01-01T00"), DUIso2Ts("2005-01-01T00:00"), DUIso2Ts("2005-01-01T00:00:00"),
			DUIso2Ts("2005-01-01T00:00:00.0"), DUIso2Ts("2005-01-01T00:00:00.0Z"));
	Test("01/01/1970",
			DUIso2Ts(""), DUIso2Ts("1970"), DUIso2Ts("1970-01"), DUIso2Ts("1970-01-01"),
			DUIso2Ts("1970-01-01T00"), DUIso2Ts("1970-01-01T00:00"), DUIso2Ts("1970-01-01T00:00:00"),
			DUIso2Ts("1970-01-01T00:00:00.0"), DUIso2Ts("1970-01-01T00:00:00.0Z"));
	Test("01/01/1970, h01:00:00", DUIso2Ts("1970-01-01T01:00:00.0Z"));
	Test("01/01/1970, h01:00:01", DUIso2Ts("1970-01-01T01:00:01.0Z"));

	Test("DUTs2Iso",
			DUTs2Iso(1, "YYYY"), DUTs2Iso(1, "YYYY-MM"), DUTs2Iso(1, "YYYY-MM-DD"), DUTs2Iso(1, DU_ISO_DATE),
			DUTs2Iso(1, "YYYY-MM-DDThh"), DUTs2Iso(1, "YYYY-MM-DDThh:mm"), DUTs2Iso(1, "YYYY-MM-DDThh:mm:ss"),
			DUTs2Iso(1, DU_ISO_DATETIME), DUTs2Iso(1), DUTs2Iso(1, "YYYY-MM-DDThh:mm:ssAltro"));

	$yy = array();
	for ($n = 0; $n <= 99; $n++)
		$yy[] = DUNormalizeYear($n);
	Test("DUNormalizeYear(today)", $yy);
	$yy = array();
	for ($n = 0; $n <= 99; $n++)
		$yy[] = DUNormalizeYear($n, DU_TODAY_CENTER, 0, 2000);
	Test("DUNormalizeYear(2000)", $yy);
	$yy = array();
	for ($n = 0; $n <= 99; $n++)
		$yy[] = DUNormalizeYear($n, DU_TODAY_CENTER, 0, 1999);
	Test("DUNormalizeYear(1999)", $yy);
	$yy = array();
	for ($n = 0; $n <= 99; $n++)
		$yy[] = DUNormalizeYear($n, DU_TODAY_CENTER, 0, 1950);
	Test("DUNormalizeYear(1950)", $yy);
	$yy = array();
	for ($n = 0; $n <= 99; $n++)
		$yy[] = DUNormalizeYear($n, DU_TODAY_FIRST);
	Test("DUNormalizeYear(First)", $yy);
	$yy = array();
	for ($n = 0; $n <= 99; $n++)
		$yy[] = DUNormalizeYear($n, DU_TODAY_LAST);
	Test("DUNormalizeYear(Last)", $yy);
	$yy = array();
	for ($n = 0; $n <= 99; $n++)
		$yy[] = DUNormalizeYear($n, DU_FROM_YEAR, 1980);
	Test("DUNormalizeYear(From1980)", $yy);
	$yy = array();
	for ($n = 0; $n <= 99; $n++)
		$yy[] = DUNormalizeYear($n, DU_TO_YEAR, 1980);
	Test("DUNormalizeYear(To1980)", $yy);

	Test(
		DUTsImplode(""),
		DUTsImplode(array()),
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 1970)),
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 1970, "h" => 0, "m" => 0, "s" => 0)),
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 1970, "h" => 0, "m" => 0, "s" => 1)),
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 1970, "h" => 1, "m" => 0, "s" => 0)),
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 1970, "h" => 1, "m" => 0, "s" => 1))
		);
	Test(
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2007, "h" => 0, "m" => 0, "s" => 0)),
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2007, "h" => 0, "m" => 0, "s" => 1)),
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2007, "h" => 0, "m" => 1, "s" => 0)),
		DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2007, "h" => 1, "m" => 0, "s" => 0))
		);
	Test(
		DUTsExplode(time()),
		DUTsExplode(0),
		DUTsExplode(1),
		DUTsExplode(-3600),
		DUTsExplode(-3599),
		DUTsExplode(DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2007, "h" => 0, "m" => 0, "s" => 0))),
		DUTsExplode(DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2007, "h" => 0, "m" => 0, "s" => 1))),
		DUTsExplode(DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2007, "h" => 0, "m" => 1, "s" => 0))),
		DUTsExplode(DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2007, "h" => 1, "m" => 0, "s" => 0))),
		DUTsExplode(DUTsImplode(array("D" => 2, "M" => 1, "Y" => 2007, "h" => 0, "m" => 0, "s" => 0))),
		DUTsExplode(DUTsImplode(array("D" => 1, "M" => 2, "Y" => 2007, "h" => 0, "m" => 0, "s" => 0))),
		DUTsExplode(DUTsImplode(array("D" => 1, "M" => 1, "Y" => 2008, "h" => 0, "m" => 0, "s" => 0)))
		);

	Test(
			"dom..dom", DUDayName(0), DUDayName(1), DUDayName(2), DUDayName(3),
			DUDayName(4), DUDayName(5), DUDayName(6), DUDayName(7)
		);
	Test("-1", DUDayName(-1));
	Test("8", DUDayName(8));

	Test(
			"dom..dom", DUDayShortName(0), DUDayShortName(1), DUDayShortName(2), DUDayShortName(3),
			DUDayShortName(4), DUDayShortName(5), DUDayShortName(6), DUDayShortName(7)
		);
	Test("-1", DUDayShortName(-1));
	Test("8", DUDayShortName(8));

	// Test code for dateutil.php ends here.

	Test("Final internal status");
	PrintFooter();	
?>
